.. _faq:

==========================
Frequently Asked Questions
==========================


What is "pre-ARD"
~~~~~~~~~~~~~~~~~

Data that is fully preprocesed but needs to be
:ref:`converted <cli_cedar_convert>` into a new format to meet the
definition of ARD.


How can I revoke OAuth2 permissions I give to this application?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This answer only applies to people who use the Google Drive for storage.

Visit `Google Account Authorized Access`_, login to the account you used to
generate the permissions, find and click the application name, and click
the "Revoke" button. The application name will depend on how you set up the
Google Drive credentials (see Google Drive :ref:`gee_creds_gdrive_dev`).


.. _Google Account Authorized Access: https://accounts.google.com/b/0/IssuedAuthSubTokens
